#ifndef	_CLASS_WRAPPER_H_
#define	_CLASS_WRAPPER_H_
//
//   File : class_wrapper.h
//   Creation date : Fri Jan 28 14:21:48 CEST 2005
//   by Tonino Imbesi(Grifisx) and Alessandro Carbone(Noldor)
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2005 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//




#include "class_widget.h"
#include "tqlistview.h"




#include "object_macros.h"

class KviKvsObject_wrapper : public KviKvsObject_widget
{
	TQ_OBJECT
  
public:
	KVSO_DECLARE_OBJECT(KviKvsObject_wrapper)
public:
	TQWidget * widget() { return (TQWidget *)object(); };
protected:
	virtual bool init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams);
	TQWidget * findTopLevelWidgetToWrap(const TQString szClass, const TQString szName);
	TQWidget * findWidgetToWrap(const char *szClass, const char *szName, TQWidget *childOf);

};



#endif	//!_CLASS_WRAPPER_H_
